@@ -145,8 +145,8 @@ class BaseModel(torch.nn.Module):
         pass
 
     @classmethod
-    def from_pretrained(cls, args, name, *, path=None, url=None):
-        model_path = auto_create(name, path=path, url=url)
+    def from_pretrained(cls, args, name, *, home_path=None, url=None):
+        model_path = auto_create(name, path=home_path, url=url)
         args = update_args_with_file(args, path=os.path.join(model_path, 'model_config.json'))
         model = get_model(args, cls)
         load_checkpoint(model, args, load_path=model_path)
@@ -154,7 +154,7 @@ class BaseModel(torch.nn.Module):
 
 class AutoModel():
     @classmethod
-    def from_pretrained(cls, args, name, *, path=None, url=None):
+    def from_pretrained(cls, args, name, *, home_path=None, url=None):
         '''Automatically find the class and instantiate it. Auto-download.
             Args:
                 args: NameSpace. will add the loaded args into it.
@@ -162,7 +162,7 @@ class AutoModel():
                 path: the parent folder of existing `name` model. Default: SAT_HOME.
                 url: manually specified url for the `name` model.
         '''
-        model_path = auto_create(name, path=path, url=url)
+        model_path = auto_create(name, path=home_path, url=url)
         args = update_args_with_file(args, path=os.path.join(model_path, 'model_config.json'))
         if not hasattr(args, 'model_class'):
             raise ValueError('model_config.json must have key "model_class" for AutoModel.from_pretrained.')
