@@ -14,7 +14,7 @@ import random
 import torch
 
 from .base_model import BaseModel, BaseMixin, non_conflict
-from SwissArmyTransformer.mpu.transformer import standard_attention, split_tensor_along_last_dim
+from SwissArmyTransformer.model.transformer import standard_attention, split_tensor_along_last_dim
 
 class CachedAutoregressiveMixin(BaseMixin):
     def __init__(self):
