@@ -74,12 +74,11 @@ def training_main(args, model_cls, forward_step_function, create_dataset_functio
     # Build model
     if isinstance(model_cls, type):
         model = get_model(args, model_cls)
-        
     else:
         model = model_cls
 
     # Config model IO
-    if args.load is not None and isinstance(model_cls, type): # If you pass a model by yourself, you need to load it by youself as well.
+    if args.load is not None:
         args.iteration = load_checkpoint(model, args)
         # if we don't load optim_states, filelock is no more needed.
         # with FileLock("/root/checkpoint_lock", timeout=-1):
@@ -108,6 +107,8 @@ def training_main(args, model_cls, forward_step_function, create_dataset_functio
             print('Finetuning Model...')
         print_args(args)
         summary_writer = get_sample_writer(base=args.summary_dir, name=args.experiment_name, iteration=args.iteration)
+        if hasattr(summary_writer, 'add_hparams'): # old version does not have this api
+            summary_writer.add_hparams(vars(args), {'_dump':0}, name=args.experiment_name, global_step=0)
 
     # Resume data loader if necessary.
     if args.resume_dataloader:
@@ -139,10 +140,9 @@ def training_main(args, model_cls, forward_step_function, create_dataset_functio
     # final testing
     if args.do_test and test_data is not None:
         prefix = 'the end of training for test data'
-        evaluate_and_print_results(prefix, iter(test_data),
+        test_loss = evaluate_and_print_results(prefix, iter(test_data),
             model, len(test_data) if args.strict_eval else args.eval_iters, args, timers, True, split='test', hooks=hooks)
 
-
 def get_model(args, model_cls):
     """Build the model."""
 
@@ -359,7 +359,11 @@ def train_step(data_iterator, model, optimizer, lr_scheduler,
     while True:
         # Forward model for one step.
         timers('forward').start()
-        lm_loss, metrics = forward_step(data_iterator, model, args, timers, **kwargs)
+        forward_ret = forward_step(data_iterator, model, args, timers, **kwargs)
+        if isinstance(forward_ret, tuple):
+            lm_loss, metrics = forward_ret
+        else:
+            lm_loss, metrics = forward_ret, {}
         timers('forward').stop()
 
         # Check nan or inf in forward, preventing it from interfering loss scaler,
